<?php

/*
 * This file is part of TBSCertBot.
 * 
 * Copyright (c) 1996-2016 TBS Internet
 * 
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

namespace TBSCertBot\API\Entities;

/**
 * Representation of a BillingOrganization
 *
 * @author TBS Internet <webmaster@tbs-internet.com>
 */
class BillingOrganization extends Organization
{
    public static function setCLIoptions(\cli\Arguments &$arguments)
    {
        $arguments->addOption('billing-name', array('description' => 'Billing organization\'s name.'));
        $arguments->addOption('billing-address-1', array('description' => 'Billing organization\'s address.'));
        $arguments->addOption('billing-address-2', array('description' => 'Billing organization\'s address.'));
        $arguments->addOption('billing-address-3', array('description' => 'Billing organization\'s address.'));
        $arguments->addOption('billing-city', array('description' => 'Billing organization\'s city.'));
        $arguments->addOption('billing-postalcode', array('description' => 'Billing organization\'s postal code.'));
        $arguments->addOption('billing-state', array('description' => 'Billing organization\'s state.'));
        $arguments->addOption('billing-country', array('description' => 'Billing organization\'s country.'));
        $arguments->addOption('billing-phone', array('description' => 'Billing organization\'s phone number.'));
        $arguments->addOption('billing-type', array('description' => 'Billing organization\'s type.'));
        $arguments->addOption('billing-number', array('description' => 'Billing organization\'s identification number.'));
        $arguments->addOption('billing-nafcode', array('description' => 'Billing organization\'s NAF code (France only).'));
        $arguments->addOption('billing-website', array('description' => 'Billing organization\'s website.'));
        $arguments->addOption('billing-vat', array('description' => 'Billing organization\'s VAT number.'));
        $arguments->addOption('billing-accounting-email', array('description' => 'Billing organization\'s accounting e-mail address.'));
    }
    
    public static function mergeOptionsWithConfig(array $options)
    {
        $config = array();
        
        if (isset($options['billing-name']) && !is_null($options['billing-name'])) {
            $config['BILLING_ORGANIZATION']['name'] = $options['billing-name'];
        }
        if (isset($options['billing-address-1']) && !is_null($options['billing-address-1'])) {
            $config['BILLING_ORGANIZATION']['address'][0] = $options['billing-address-1'];
        }
        if (isset($options['billing-address-2']) && !is_null($options['billing-address-2'])) {
            $config['BILLING_ORGANIZATION']['address'][1] = $options['billing-address-2'];
        }
        if (isset($options['billing-address-3']) && !is_null($options['billing-address-3'])) {
            $config['BILLING_ORGANIZATION']['address'][2] = $options['billing-address-3'];
        }
        if (isset($options['billing-city']) && !is_null($options['billing-city'])) {
            $config['BILLING_ORGANIZATION']['city'] = $options['billing-city'];
        }
        if (isset($options['billing-postalcode']) && !is_null($options['billing-postalcode'])) {
            $config['BILLING_ORGANIZATION']['postalCode'] = $options['billing-postalcode'];
        }
        if (isset($options['billing-state']) && !is_null($options['billing-state'])) {
            $config['BILLING_ORGANIZATION']['state'] = $options['billing-state'];
        }
        if (isset($options['billing-country']) && !is_null($options['billing-country'])) {
            $config['BILLING_ORGANIZATION']['country'] = $options['billing-country'];
        }
        if (isset($options['billing-phone']) && !is_null($options['billing-phone'])) {
            $config['BILLING_ORGANIZATION']['phoneNumber'] = $options['billing-phone'];
        }
        if (isset($options['billing-type']) && !is_null($options['billing-type'])) {
            $config['BILLING_ORGANIZATION']['type'] = $options['billing-type'];
        }
        if (isset($options['billing-number']) && !is_null($options['billing-number'])) {
            $config['BILLING_ORGANIZATION']['number'] = $options['billing-number'];
        }
        if (isset($options['billing-nafcode']) && !is_null($options['billing-nafcode'])) {
            $config['BILLING_ORGANIZATION']['nafCode'] = $options['billing-nafcode'];
        }
        if (isset($options['billing-website']) && !is_null($options['billing-website'])) {
            $config['BILLING_ORGANIZATION']['website'] = $options['billing-website'];
        }
        if (isset($options['billing-vat']) && !is_null($options['billing-vat'])) {
            $config['BILLING_ORGANIZATION']['vatNumber'] = $options['billing-vat'];
        }
        if (isset($options['billing-accounting-email']) && !is_null($options['billing-accounting-email'])) {
            $config['BILLING_ORGANIZATION']['accountingEmailAddress'] = $options['billing-accounting-email'];
        }
        
        if (!empty($config)) {
            \TBSCertBot\Config::getConfig()->update($config);
        }
    }
}
