<?php

/*
 * This file is part of TBSCertBot.
 * 
 * Copyright (c) 1996-2016 TBS Internet
 * 
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

namespace TBSCertBot\API\Entities;

/**
 * Representation of a CorporateContact
 *
 * @author TBS Internet <webmaster@tbs-internet.com>
 */
class CorporateContact extends Contact
{   
    public function getXmlRpc()
    {
        return array(
            'civiliteAdm' => \TBSCertBot\API\Helper::mapTitleToId($this->title),
            'nomAdm'        => $this->lastName,
            'prenomAdm'     => $this->firstName,
            'fonctionAdm'   => $this->function,
            'telAdm'        => $this->phoneNumber,
            'emailAdm'      => $this->emailAddress,
            'langueComAdm' => $this->language
        );
    }
    
    public static function setCLIoptions(\cli\Arguments &$arguments)
    {
        $arguments->addOption('cc-title', array('description' => 'Corporate contact\'s title.'));
        $arguments->addOption('cc-lastname', array('description' => 'Corporate contact\'s last name.'));
        $arguments->addOption('cc-firstname', array('description' => 'Corporate contact\'s first name.'));
        $arguments->addOption('cc-function', array('description' => 'Corporate contact\'s function.'));
        $arguments->addOption('cc-phone', array('description' => 'Corporate contact\'s phone number.'));
        $arguments->addOption('cc-email', array('description' => 'Corporate contact\'s e-mail address.'));
        $arguments->addOption('cc-language', array('description' => 'Corporate contact\'s language.'));
    }
    
    public static function mergeOptionsWithConfig(array $options)
    {
        $config = array();
        
        if (isset($options['cc-title']) && !is_null($options['cc-title'])) {
            $config['CORPORATE_CONTACT']['title'] = $options['cc-title'];
        }
        if (isset($options['cc-lastname']) && !is_null($options['cc-lastname'])) {
            $config['CORPORATE_CONTACT']['lastName'] = $options['cc-lastname'];
        }
        if (isset($options['cc-firstname']) && !is_null($options['cc-firstname'])) {
            $config['CORPORATE_CONTACT']['firstName'] = $options['cc-firstname'];
        }
        if (isset($options['cc-function']) && !is_null($options['cc-function'])) {
            $config['CORPORATE_CONTACT']['function'] = $options['cc-function'];
        }
        if (isset($options['cc-phone']) && !is_null($options['cc-phone'])) {
            $config['CORPORATE_CONTACT']['phoneNumber'] = $options['cc-phone'];
        }
        if (isset($options['cc-email']) && !is_null($options['cc-email'])) {
            $config['CORPORATE_CONTACT']['emailAddress'] = $options['cc-email'];
        }
        if (isset($options['cc-language']) && !is_null($options['cc-language'])) {
            $config['CORPORATE_CONTACT']['language'] = $options['cc-language'];
        }
        
        if (!empty($config)) {
            \TBSCertBot\Config::getConfig()->update($config);
        }
    }
    
    public static function load(array $info)
    {
        if (isset($info['title']) && !is_null($info['title'])) {
            $title = $info['title'];
        }
        if (isset($info['firstName']) && !is_null($info['firstName'])) {
            $firstName = $info['firstName'];
        }
        if (isset($info['lastName']) && !is_null($info['lastName'])) {
            $lastName = $info['lastName'];
        }
        if (isset($info['function']) && !is_null($info['function'])) {
            $function = $info['function'];
        }
        if (isset($info['phoneNumber']) && !is_null($info['phoneNumber'])) {
            $phoneNumber = $info['phoneNumber'];
        }
        if (isset($info['emailAddress']) && !is_null($info['emailAddress'])) {
            $emailAddress = $info['emailAddress'];
        }
        if (isset($info['language']) && !is_null($info['language'])) {
            $language = $info['language'];
        }
        
        return new CorporateContact(
                $title,
                $firstName,
                $lastName,
                $function,
                $phoneNumber,
                $emailAddress,
                $language                
        );
    }
}
