<?php

/*
 * This file is part of TBSCertBot.
 * 
 * Copyright (c) 1996-2016 TBS Internet
 * 
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

namespace TBSCertBot\API\Entities;

/**
 *
 * Interface that formalizes an API entity.
 * Any structure (e.g organization, contact) that will be sent to the API implements Entity
 * 
 * @author TBS Internet <webmaster@tbs-internet.com>
 */
interface Entity
{
    /**
     * Function that will be used to validate the values of properties.
     */
    public function validate();
    
    /**
     * Interactive fallback that can be called if the values of the entity are missing or incorrect
     */
    public function interactiveFallback();
    
    /**
     * Generates the XMLRPC array that will be converted to XML
     */
    public function getXmlRpc();
    
    /**
     * Builds the array that will be used for serialization
     * @return array Array to be serialized
     */
    public function save();
    
    /**
     * 
     * Gets options from the CLI
     * 
     * @param \cli\Arguments $arguments
     */
    public static function setCLIoptions(\cli\Arguments &$arguments);
    
    /**
     * 
     * Merges options from the cli with the config
     * Cli options take precedence
     * 
     * @param array $options
     */
    public static function mergeOptionsWithConfig(array $options);
    
    /**
     * 
     * Deserialization from the stored file
     * 
     * @param array $info
     */
    public static function load(array $info);
}
