<?php

/*
 * This file is part of TBSCertBot.
 * 
 * Copyright (c) 1996-2016 TBS Internet
 * 
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

namespace TBSCertBot\API\Entities;

/**
 * Representation of a LegalContact
 * Used for RGS/EIDAS certificates
 *
 * @author TBS Internet <webmaster@tbs-internet.com>
 */
class LegalContact extends Contact
{    
    public function getXmlRpc()
    {
        return array(
            'civiliteRespLegal' => \TBSCertBot\API\Helper::mapTitleToId($this->title),
            'nomRespLegal' => $this->lastName,
            'prenomRespLegal' => $this->firstName,
            'fonctionRespLegal' => $this->function,
            'telRespLegal' => $this->phoneNumber,
            'emailRespLegal' => $this->emailAddress,
            'langueComRespLegal' => $this->language
        );
    }
    
    public static function setCLIoptions(\cli\Arguments &$arguments)
    {
        $arguments->addOption('legal-title', array('description' => 'Legal contact\'s title.'));
        $arguments->addOption('legal-lastname', array('description' => 'Legal contact\'s last name.'));
        $arguments->addOption('legal-firstname', array('description' => 'Legal contact\'s first name.'));
        $arguments->addOption('legal-function', array('description' => 'Legal contact\'s function.'));
        $arguments->addOption('legal-phone', array('description' => 'Legal contact\'s phone number.'));
        $arguments->addOption('legal-email', array('description' => 'Legal contact\'s e-mail address.'));
        $arguments->addOption('legal-language', array('description' => 'Legal contact\'s language.'));
    }
    
    public static function mergeOptionsWithConfig(array $options)
    {
        $config = array();
        
        if (isset($options['legal-title']) && !is_null($options['legal-title'])) {
            $config['LEGAL_CONTACT']['title'] = $options['legal-title'];
        }
        if (isset($options['legal-lastname']) && !is_null($options['legal-lastname'])) {
            $config['LEGAL_CONTACT']['lastName'] = $options['legal-lastname'];
        }
        if (isset($options['legal-firstname']) && !is_null($options['legal-firstname'])) {
            $config['LEGAL_CONTACT']['firstName'] = $options['legal-firstname'];
        }
        if (isset($options['legal-function']) && !is_null($options['legal-function'])) {
            $config['LEGAL_CONTACT']['function'] = $options['legal-function'];
        }
        if (isset($options['legal-phone']) && !is_null($options['legal-phone'])) {
            $config['LEGAL_CONTACT']['phoneNumber'] = $options['legal-phone'];
        }
        if (isset($options['legal-email']) && !is_null($options['legal-email'])) {
            $config['LEGAL_CONTACT']['emailAddress'] = $options['legal-email'];
        }
        if (isset($options['legal-language']) && !is_null($options['legal-language'])) {
            $config['LEGAL_CONTACT']['language'] = $options['legal-language'];
        }
        
        if (!empty($config)) {
            \TBSCertBot\Config::getConfig()->update($config);
        }
    }
    
    public static function load(array $info)
    {
        if (isset($info['title']) && !is_null($info['title'])) {
            $title = $info['title'];
        }
        if (isset($info['firstName']) && !is_null($info['firstName'])) {
            $firstName = $info['firstName'];
        }
        if (isset($info['lastName']) && !is_null($info['lastName'])) {
            $lastName = $info['lastName'];
        }
        if (isset($info['function']) && !is_null($info['function'])) {
            $function = $info['function'];
        }
        if (isset($info['phoneNumber']) && !is_null($info['phoneNumber'])) {
            $phoneNumber = $info['phoneNumber'];
        }
        if (isset($info['emailAddress']) && !is_null($info['emailAddress'])) {
            $emailAddress = $info['emailAddress'];
        }
        if (isset($info['language']) && !is_null($info['language'])) {
            $language = $info['language'];
        }
        
        return new LegalContact(
                $title,
                $firstName,
                $lastName,
                $function,
                $phoneNumber,
                $emailAddress,
                $language
        );
    }
}
