<?php

/*
 * This file is part of TBSCertBot.
 * 
 * Copyright (c) 1996-2016 TBS Internet
 * 
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

namespace TBSCertBot\API\Entities;

/**
 * Representation of the Miscellaneous structure
 *
 * @author TBS Internet <webmaster@tbs-internet.com>
 */
class Miscellaneous implements Entity
{
    private $promotionalCode;
    private $customerNote;
    private $customerReference;
    private $reissueReason;
    
    public function __construct(
            $promotionalCode = null,
            $customerNote = null,
            $customerReference = null,
            $reissueReason = null
            ) {
        $this->promotionalCode = $promotionalCode;
        $this->customerNote = $customerNote;
        $this->customerReference = $customerReference;
        $this->reissueReason = $reissueReason;
    }
    
    public function getPromotionalCode()
    {
        return $this->promotionalCode;
    }
    
    public function getCustomerNote()
    {
        return $this->customerNote;
    }
    
    public function getCustomerReference()
    {
        return $this->customerReference;
    }
    
    public function getReissueReason()
    {
        return $this->reissueReason;
    }
    
    /**
     * Function that will be used to validate the values of properties.
     * 
     * @todo Implement a validation for reissuance only
     */
    public function validate()
    {

    }
    
    /**
     * Interactive fallback that can be called if the values of the entity are missing or incorrect
     * 
     * @todo Implement a fallback for reissue reason for reissuance only
     */
    public function interactiveFallback()
    {
        
    }
    
    public function save()
    {
        $info = array();
        
        if (isset($this->promotionalCode) && !is_null($this->promotionalCode)) {
            $info['promotionalCode'] = $this->promotionalCode;
        }
        if (isset($this->customerNote) && !is_null($this->customerNote)) {
            $info['customerNote'] = $this->customerNote;
        }
        if (isset($this->customerReference) && !is_null($this->customerReference)) {
            $info['customerReference'] = $this->customerReference;
        }
        if (isset($this->reissueReason) && !is_null($this->reissueReason)) {
            $info['reissueReason'] = $this->reissueReason;
        }
        
        return $info;
    }
    
    public function getXmlRpc()
    {
        return array(
            'codePromo' => $this->promotionalCode,
            'notesClient' => $this->customerNote,
            'refClient' => $this->customerReference,
            'raisonRefab' => $this->reissueReason
        );
    }
    
    public static function setCLIoptions(\cli\Arguments &$arguments)
    {
        $arguments->addOption('promo', array('description' => 'Promotional code.'));
        $arguments->addOption('note', array('description' => 'Custom note.'));
        $arguments->addOption('customer-ref', array('description' => 'Customer\'s reference.'));
        $arguments->addOption('reissue-reason', array('description' => 'Reason for requesting certificate\'s reissuance.'));
    }
    
    public static function mergeOptionsWithConfig(array $options)
    {
        $config = array();
        
        if (isset($options['promo']) && !is_null($options['promo'])) {
            $config['MISCELLANEOUS']['promotionalCode'] = $options['promo'];
        }
        if (isset($options['note']) && !is_null($options['note'])) {
            $config['MISCELLANEOUS']['customerNote'] = $options['note'];
        }
        if (isset($options['customer-ref']) && !is_null($options['customer-ref'])) {
            $config['MISCELLANEOUS']['customerReference'] = $options['customer-ref'];
        }
        if (isset($options['reissue-reason']) && !is_null($options['reissue-reason'])) {
            $config['MISCELLANEOUS']['reissueReason'] = $options['reissue-reason'];
        }
        
        if (!empty($config)) {
            \TBSCertBot\Config::getConfig()->update($config);
        }
    }
    
    public static function load(array $info)
    {
        if (isset($info['promotionalCode']) && !is_null($info['promotionalCode'])) {
            $promotionalCode = $info['promotionalCode'];
        }
        if (isset($info['customerNote']) && !is_null($info['customerNote'])) {
            $customerNote = $info['customerNote'];
        }
        if (isset($info['customerReference']) && !is_null($info['customerReference'])) {
            $customerReference = $info['customerReference'];
        }
        if (isset($info['reissueReason']) && !is_null($info['reissueReason'])) {
            $reissueReason = $info['reissueReason'];
        }
        
        return new Miscellaneous(
                $promotionalCode,
                $customerNote,
                $customerReference,
                $reissueReason
        );
    }
}
