<?php

/*
 * This file is part of TBSCertBot.
 * 
 * Copyright (c) 1996-2016 TBS Internet
 * 
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

namespace TBSCertBot\API\Entities;

/**
 * Representation of a TechnicalContact
 *
 * @author TBS Internet <webmaster@tbs-internet.com>
 */
class TechnicalContact extends Contact
{
    public function getXmlRpc()
    {
        return array(
            'civiliteTech' => \TBSCertBot\API\Helper::mapTitleToId($this->title),
            'nomTech' => $this->lastName,
            'prenomTech' => $this->firstName,
            'fonctionTech' => $this->function,
            'telTech' => $this->phoneNumber,
            'emailTech' => $this->emailAddress,
            'langueComTech' => $this->language
        );
    }
    
    public static function setCLIoptions(\cli\Arguments &$arguments)
    {
        $arguments->addOption('tc-title', array('description' => 'Technical contact\'s title.'));
        $arguments->addOption('tc-lastname', array('description' => 'Technical contact\'s last name.'));
        $arguments->addOption('tc-firstname', array('description' => 'Technical contact\'s first name.'));
        $arguments->addOption('tc-function', array('description' => 'Technical contact\'s function.'));
        $arguments->addOption('tc-phone', array('description' => 'Technical contact\'s phone number.'));
        $arguments->addOption('tc-email', array('description' => 'Technical contact\'s e-mail address.'));
        $arguments->addOption('tc-language', array('description' => 'Technical contact\'s language.'));
    }
    
    public static function mergeOptionsWithConfig(array $options)
    {
        $config = array();
        
        if (isset($options['tc-title']) && !is_null($options['tc-title'])) {
            $config['TECHNICAL_CONTACT']['title'] = $options['tc-title'];
        }
        if (isset($options['tc-lastname']) && !is_null($options['tc-lastname'])) {
            $config['TECHNICAL_CONTACT']['lastName'] = $options['tc-lastname'];
        }
        if (isset($options['tc-firstname']) && !is_null($options['tc-firstname'])) {
            $config['TECHNICAL_CONTACT']['firstName'] = $options['tc-firstname'];
        }
        if (isset($options['tc-function']) && !is_null($options['tc-function'])) {
            $config['TECHNICAL_CONTACT']['function'] = $options['tc-function'];
        }
        if (isset($options['tc-phone']) && !is_null($options['tc-phone'])) {
            $config['TECHNICAL_CONTACT']['phoneNumber'] = $options['tc-phone'];
        }
        if (isset($options['tc-email']) && !is_null($options['tc-email'])) {
            $config['TECHNICAL_CONTACT']['emailAddress'] = $options['tc-email'];
        }
        if (isset($options['tc-language']) && !is_null($options['tc-language'])) {
            $config['TECHNICAL_CONTACT']['language'] = $options['tc-language'];
        }
        
        if (!empty($config)) {
            \TBSCertBot\Config::getConfig()->update($config);
        }
    }
    
    public static function load(array $info)
    {
        if (isset($info['title']) && !is_null($info['title'])) {
            $title = $info['title'];
        }
        if (isset($info['firstName']) && !is_null($info['firstName'])) {
            $firstName = $info['firstName'];
        }
        if (isset($info['lastName']) && !is_null($info['lastName'])) {
            $lastName = $info['lastName'];
        }
        if (isset($info['function']) && !is_null($info['function'])) {
            $function = $info['function'];
        }
        if (isset($info['phoneNumber']) && !is_null($info['phoneNumber'])) {
            $phoneNumber = $info['phoneNumber'];
        }
        if (isset($info['emailAddress']) && !is_null($info['emailAddress'])) {
            $emailAddress = $info['emailAddress'];
        }
        if (isset($info['language']) && !is_null($info['language'])) {
            $language = $info['language'];
        }
        
        return new TechnicalContact(
                $title,
                $firstName,
                $lastName,
                $function,
                $phoneNumber,
                $emailAddress,
                $language
        );
    }
}
