<?php

/*
 * This file is part of TBSCertBot.
 * 
 * Copyright (c) 1996-2016 TBS Internet
 * 
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

namespace TBSCertBot\API\Methods\Order;

/**
 * Request implementation to order certificates
 *
 * @author TBS Internet <webmaster@tbs-internet.com>
 */
class Request extends \TBSCertBot\API\Methods\XmlRpcRequest
{
    const ORDER_APPLICATION = 'api-operations.php';
    const ORDER_METHOD_NAME = 'achat';
    
    private $product;
    private $request;
    private $organization;
    private $corporateContact;
    private $payment;
    
    // Optional values.
    private $technicalContact;
    private $legalContact;
    private $billingOrganization;
    private $miscellaneous;
    
    public function __construct(
    \TBSCertBot\API\Entities\Product $product,
    \TBSCertBot\API\Entities\Request $request,
    \TBSCertBot\API\Entities\Organization $organization,
    \TBSCertBot\API\Entities\CorporateContact $corporateContact,
    \TBSCertBot\API\Entities\Payment $payment,
    \TBSCertBot\API\Entities\TechnicalContact $technicalContact = null,
    \TBSCertBot\API\Entities\LegalContact $legalContact = null,
    \TBSCertBot\API\Entities\Organization $billingOrganization = null,
    \TBSCertBot\API\Entities\Miscellaneous $miscellaneous = null,
    $reference = null
    ) {
        $this->product = $product;
        $this->request = $request;
        $this->organization = $organization;
        $this->corporateContact = $corporateContact;
        $this->payment = $payment;
        
        // Optional values.
        $this->technicalContact = $technicalContact;
        $this->legalContact = $legalContact;
        $this->billingOrganization = $billingOrganization;
        $this->miscellaneous = $miscellaneous;
        $this->reference = $reference;
        
        $this->setApplicationAndMethodName();
    }
    
    /**
     * Sets the application and method name used to send API requests
     */
    private function setApplicationAndMethodName()
    {
        $this->application = self::ORDER_APPLICATION;
        $this->methodName = self::ORDER_METHOD_NAME;
    }
    
    /**
     * 
     * Builds the serialization array
     * 
     * @return array
     */
    public function save()
    {
        return array(
            'PRODUCT' => $this->product->save(),
            'REQUEST' => $this->request->save(),
            'ORGANIZATION' => $this->organization->save(),
            'CORPORATE_CONTACT' => $this->corporateContact->save(),
            'PAYMENT' => $this->payment->save(),
            'TECHNICAL_CONTACT' => $this->technicalContact->save(),
            'LEGAL_CONTACT' => $this->legalContact->save(),
            'BILLING_ORGANIZATION' => $this->billingOrganization->save(),
            'MISCELLANEOUS' => $this->miscellaneous->save()
        );
    }
    
    public function getXmlRpc()
    {
        $subXmlRpc = array(
            'produit' => $this->product->getXmlRpc(),
            'requete' => $this->request->getXmlRpc(),
            'organisation' => $this->organization->getXmlRpc(),
            'contactAdm' => $this->corporateContact->getXmlRpc(),
            'paiement' => $this->payment->getXmlRpc()
        );
        
        // Optional values.
        if (!is_null($this->technicalContact)) {
            $subXmlRpc['contactTech'] = $this->technicalContact->getXmlRpc();
        }
        if (!is_null($this->legalContact)) {
            $subXmlRpc['contactRespLegal'] = $this->legalContact->getXmlRpc();
        }
        if (!is_null($this->billingOrganization)) {
            $subXmlRpc['compagnieFact'] = $this->billingOrganization->getXmlRpc();
        }
        if (!is_null($this->miscellaneous)) {
            $subXmlRpc['divers'] = $this->miscellaneous->getXmlRpc();
        }
        if (!is_null($this->reference)) {
            $subXmlRpc['refDemande'] = $this->reference;
        }
        
        return array(
            'identification' => array(
                'utilisateur' => \TBSCertBot\Config::getConfig()->getAPIUsername(),
                'motDePasse' => \TBSCertBot\Config::getConfig()->getAPIPassword()
            ),
            'demande' => $subXmlRpc
        );
    }

    protected function handleResponse($response)
    {
        return new Response($response);
    }
}
