<?php

/*
 * This file is part of TBSCertBot.
 * 
 * Copyright (c) 1996-2016 TBS Internet
 * 
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

namespace TBSCertBot\API\Methods\Order;

/**
 * Response implementation to order certificates
 *
 * @author TBS Internet <webmaster@tbs-internet.com>
 * @todo Add DCV_Status included in the response to that class?
 */
class Response extends \TBSCertBot\API\Methods\XmlRpcResponse
{
    protected $code;
    protected $message;
    
    protected $tbsReference;
    protected $caReference;
    
    public function __construct(\PhpXmlRpc\Response $xmlRpcResponse)
    {
        parent::__construct($xmlRpcResponse);
        
        $this->tbsReference = $this->rawMessageResponse['demande']['refTBS'];
        
        if (isset($this->rawMessageResponse['demande']['refCA'])
                && !empty($this->rawMessageResponse['demande']['refCA'])
        ) {
            $this->caReference = $this->rawMessageResponse['demande']['refCA'];
        }
    }
    
    public function getCode()
    {
        return $this->code;
    }
    
    public function getMessage()
    {
        return $this->message;
    }
    
    public function getTBSReference()
    {
        return $this->tbsReference;
    }
    
    public function getCAReference()
    {
        return $this->caReference;
    }
    
    protected function handleMessage()
    {
        if (!is_null($this->rawMessageResponse['demande'])) {
            // Only handle the first element.
            if (is_array($this->rawMessageResponse['demande']) && (count($this->rawMessageResponse['demande']) > 0)
                    && !array_key_exists('codeReponse', $this->rawMessageResponse['demande'])) {
                $this->rawMessageResponse['demande'] = $this->rawMessageResponse['demande'][0];
            }
            $this->code = $this->rawMessageResponse['demande']['codeReponse'];
            // We squeeze that message as it is in French...
            //$this->message = $this->rawMessageResponse['demande']['messageReponse'];
            $this->message = \TBSCertBot\API\Helper::getErrorMessage($this->code);
            
        } else {
            throw new \Exception("Invalid response from server (no 'demande' structure)");
        }
    }
}
