<?php

/*
 * This file is part of TBSCertBot.
 * 
 * Copyright (c) 1996-2016 TBS Internet
 * 
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

namespace TBSCertBot\API\Methods\Recover;

/**
 * Request implementation of the Recover feature
 *
 * @author TBS Internet <webmaster@tbs-internet.com>
 */
class Request extends \TBSCertBot\API\Methods\XmlRpcRequest
{
    const RECOVER_APPLICATION = 'api-infos.php';
    const RECOVER_METHOD_NAME = 'recuperer';
    
    private $uuid;
    
    
    public function __construct($uuid)
    {
        try {
            if (\TBSCertBot\Crypto\Helper::isUuid($uuid)) {
                $this->uuid = $uuid;
            } else {
                throw new \Exception("The unique identifier is not an UUID.");
            }
        } catch (\Exception $e) {
            throw $e;
        }
        
        self::setApplicationAndMethodName();
    }
    
    /**
     * Sets the application and method name used to send API requests
     */
    private function setApplicationAndMethodName()
    {
        $this->application = self::RECOVER_APPLICATION;
        $this->methodName = self::RECOVER_METHOD_NAME;
    }
    
    public function getXmlRpc()
    {
        return array(
            'identification' => array(
                'utilisateur' => \TBSCertBot\Config::getConfig()->getAPIUsername(),
                'motDePasse' => \TBSCertBot\Config::getConfig()->getAPIPassword()
            ),
            'identifiantUnique' => $this->uuid
        );
    }

    protected function handleResponse($response)
    {
        return new Response($response);
    }

}

