<?php

/*
 * This file is part of TBSCertBot.
 * 
 * Copyright (c) 1996-2016 TBS Internet
 * 
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

namespace TBSCertBot\API\Methods\Renewal;

/**
 * Request implementation of certificate renewal
 *
 * @author TBS Internet <webmaster@tbs-internet.com>
 */
class Request extends \TBSCertBot\API\Methods\Order\Request
{
    const RENEWAL_METHOD_NAME = 'renouvellement';
    
    private $certificate;
    
    public function __construct(
            \TBSCertBot\API\Entities\Certificate $certificate,
            \TBSCertBot\API\Entities\Product $product,
            \TBSCertBot\API\Entities\Request $request,
            \TBSCertBot\API\Entities\Organization $organization,
            \TBSCertBot\API\Entities\Contact $corporateContact,
            \TBSCertBot\API\Entities\Payment $payment,
            \TBSCertBot\API\Entities\Contact $technicalContact = null,
            \TBSCertBot\API\Entities\Contact $legalContact = null,
            \TBSCertBot\API\Entities\Organization $billingOrganization = null,
            \TBSCertBot\API\Entities\Miscellaneous $miscellaneous = null,
            $reference = null
            )
    {
        parent::__construct(
                $product,
                $request,
                $organization,
                $corporateContact,
                $payment,
                $technicalContact,
                $legalContact,
                $billingOrganization,
                $miscellaneous,
                $reference
            );
        
        $this->certificate = $certificate;
        
        $this->setMethodName();
    }
    
    /**
     * Only sets the Method name because this class inherits from its order equivalent.
     * The method name is used to send API requests.
     */
    private function setMethodName()
    {
        $this->methodName = self::RENEWAL_METHOD_NAME;
    }
    
    public function validate()
    {
        try {
            parent::validate();
            $this->certificate->validate();
        } catch (\Exception $e) {
            throw $e;
        }
    }
    
    public function getXmlRpc()
    {
        $xmlRpc = parent::getXmlRpc();
        
        $xmlRpc['demande']['certificat'] = $this->certificate->getXmlRpc();
        
        return $xmlRpc;
    }
    
    protected function handleResponse($response)
    {
        return new Response($response);
    }
}
