<?php

/*
 * This file is part of TBSCertBot.
 * 
 * Copyright (c) 1996-2016 TBS Internet
 * 
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

namespace TBSCertBot\API\Methods\Status;

/**
 * Request implementation of the status
 *
 * @author TBS Internet <webmaster@tbs-internet.com>
 */
class Request extends \TBSCertBot\API\Methods\XmlRpcRequest
{
    const STATUS_APPLICATION = 'api-infos.php';
    const STATUS_METHOD_NAME = 'statut';
    
    /**
     *
     * @var array Types of responses available
     */
    private static $requestTypeStatus = array(
        'full' => 0,
        'state-certificate-validity' => 1,
        'state' => 2
    );
    
    /**
     *
     * @var array Available certificate formats
     */
    private static $requestTypeCertificate = array(
        'x509' => 'X509',
        'pkcs7' => 'PKCS7',
        'chain' => 'chaine'
    );
    
    private $certificate;
    
    // Optional values.
    private $reference;
    
    private $requestType;
    private $responseType;
    
    public function __construct(
            $certificate,
            $reference = null
    ) {        
        $this->certificate = $certificate; 
        $this->reference = $reference;
        
        $this->requestType = self::$requestTypeStatus['state-certificate-validity'];
        $this->responseType = self::$requestTypeCertificate['x509'];
        
        $this->setApplicationAndMethodName();
    }
    
    /**
     * Sets the application and method name used to send API requests
     */
    private function setApplicationAndMethodName()
    {
        $this->application = self::STATUS_APPLICATION;
        $this->methodName = self::STATUS_METHOD_NAME;
    }
    
    public function getXmlRpc()
    {
        $subXmlRpc = array(
            'refDemande' => $this->reference,
            'certificat' => $this->certificate->getXmlRpc(),
        );
        
        if (isset($this->requestType) && !is_null($this->requestType)) {
            array_push($subXmlRpc, array('typeDemande' => $this->requestType));
        }
        
        if (isset($this->responseType) && !is_null($this->responseType)) {
            array_push($subXmlRpc, array('typeReponse' => $this->responseType));
        }
                
        return array(
            'identification' => array(
                'utilisateur' => \TBSCertBot\Config::getConfig()->getAPIUsername(),
                'motDePasse' => \TBSCertBot\Config::getConfig()->getAPIPassword()
            ),
            'demande' => $subXmlRpc
        );
    }

    protected function handleResponse($response)
    {
        return new Response($response);
    }
}
