<?php

/*
 * This file is part of TBSCertBot.
 * 
 * Copyright (c) 1996-2016 TBS Internet
 * 
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

namespace TBSCertBot\API\Methods\Status;

/**
 * Response implementation implementation of the status
 *
 * @author TBS Internet <webmaster@tbs-internet.com>
 * @todo Add DCV_Status included in the response to that class?
 */
class Response extends \TBSCertBot\API\Methods\XmlRpcResponse
{
    private $code;
    private $message;
    
    /**
     * 
     * @var array List of Statuses returned by the TBS API
     */
    private static $tbsStatus = array(
        -3 => 'Awaiting info',
        -2 => 'Reissue',
        -1 => 'Cancelled',
        0  => 'Processing',
        1  => 'Currently Valid',
        2  => 'Expired',
        3  => 'Revoked',
        4  => 'Audit running',
        5  => 'Audit OK',
        6  => 'Pre-audit OK',
        7  => 'Checking SANs',
        8  => 'Vetting OK',
        9  => 'Vetting finished',
        10 => 'Phone call running',
        11 => 'To be ordered',
        12 => 'To be processed'
    );
    
    /**
     *
     * @var array List of statuses that might be more precise
     */
    private static $tbsStatusExtra = array(
        'PROPOSITION'             => 'Quotation',
        'SIGNEE'                  => 'Signed',
        'REALISEE'                => 'Achieved',
        'FACTUREE'                => 'Invoiced',
        'PAYEE'                   => 'Paid',
        'SANS SUITE'              => 'Discarded',
        'CDE EN LIGNE'            => 'Awaiting payment',
        'PAY MARQUE'              => 'Marked as Paid',
        'SS - REMB'               => 'Discarded, refunded',
        'SAISI'                   => 'Processing',
        'SS - A REMB'             => 'To be refunded',
        'Attente de confirmation' => 'Pending confirmation',
        'Attente de CSR'          => 'Pending CSR',
        'SS - SOMMEIL'            => 'Awaiting info',
        'PROPO ss cond contract'  => 'Pending contract acceptance',
        'Attente DCV'             => 'Awaiting DCV',
        'Attente refabrication'   => 'Awaiting reissue',
        'Approbation finale'      => 'Awaiting delivery',
        'SS - ATT RETENUE'        => 'Pending holdback settlement',
        'SS - RETENUE PAYEE'      => 'Cancelled',
        'Attente approbation'     => 'Awaiting approval'
    );
    
    private $tbsReference;
    private $caReference;
    
    private $statusCode;
    private $statusMessage;
    private $statusMessageExtra;
    
    private $certificatePEM;
    private $chainPEM;
    
    private $beginDate;
    private $endDate;
    
    private $dcv;
    
    private $renewed;
    private $renewedByTbsReference;
    
    public function __construct(\PhpXmlRpc\Response $xmlRpcResponse)
    {
        parent::__construct($xmlRpcResponse);
        
        $this->tbsReference = $this->rawMessageResponse['demande']['refTBS'];
        if (isset($this->rawMessageResponse['demande']['refCA'])
            && !empty($this->rawMessageResponse['demande']['refCA'])) {
            $this->caReference = $this->rawMessageResponse['demande']['refCA'];
        }
        if (isset($this->rawMessageResponse['demande']['statut'])
            && !empty($this->rawMessageResponse['demande']['statut'])) {
            $this->statusCode = $this->rawMessageResponse['demande']['statut'][0];
            $this->statusMessage = self::$tbsStatus[$this->statusCode];
            if (isset($this->rawMessageResponse['demande']['statut'][2])) {
                $this->statusMessageExtra = 
                        self::$tbsStatusExtra[$this->rawMessageResponse['demande']['statut'][2]];
            }
        }

        if (isset($this->rawMessageResponse['demande']['certificat'])) {
            if(isset($this->rawMessageResponse['demande']['certificat']['x509'])
            && !empty($this->rawMessageResponse['demande']['certificat']['x509'])) {
                $this->certificatePEM = $this->rawMessageResponse['demande']['certificat']['x509'];
            }
            if (isset($this->rawMessageResponse['demande']['certificat']['chaine'])
            && !empty($this->rawMessageResponse['demande']['certificat']['chaine'])) {
                $this->chainPEM = $this->rawMessageResponse['demande']['certificat']['chaine'];
            }
            if (isset($this->rawMessageResponse['demande']['certificat']['dateDebut'])
            && !empty($this->rawMessageResponse['demande']['certificat']['dateDebut'])) {
                $this->beginDate = $this->rawMessageResponse['demande']['certificat']['dateDebut'];
            }
            if (isset($this->rawMessageResponse['demande']['certificat']['dateFin'])
            && !empty($this->rawMessageResponse['demande']['certificat']['dateFin'])) {
                $this->endDate = $this->rawMessageResponse['demande']['certificat']['dateFin'];
            }
        }
        
        
        if (isset($this->rawMessageResponse['demande']['DCV_Status'])
            && !empty($this->rawMessageResponse['demande']['DCV_Status'])) {
                $this->dcv = $this->rawMessageResponse['demande']['DCV_Status'];
        }
        
        if(isset($this->rawMessageResponse['demande']['estRenouvele'])
                && !empty($this->rawMessageResponse['demande']['estRenouvele'])) {
            $this->renewed = true;
            $this->renewedByTbsReference = $this->rawMessageResponse['demande']['estRenouvele'];
        } else {
            $this->renewed = false;
            $this->renewedByTbsReference = null;
        }
    }
    
    public function getCode()
    {
        return $this->code;
    }
    
    public function getMessage()
    {
        return $this->message;
    }
    
    public static function getTbsStatus() {
        return self::$tbsStatus;
    }
    
    public static function getTbsStatusExtra() {
        return self::$tbsStatusExtra;
    }
    
    public function getTBSReference()
    {
        return $this->tbsReference;
    }
    
    public function getCAReference()
    {
        return $this->caReference;
    }
    
    public function getStatusCode()
    {
        return $this->statusCode;
    }
    
    public function getStatusMessage()
    {
        return $this->statusMessage;
    }
    
    public function getStatusMessageExtra()
    {
        return $this->statusMessageExtra;
    }
    
    public function getCertificatePEM()
    {
        return $this->certificatePEM;
    }
    
    public function getChainPEM()
    {
        return $this->chainPEM;
    }
    
    public function getBeginDate()
    {
        return $this->beginDate;
    }
    
    public function getEndDate()
    {
        return $this->endDate;
    }
    
    public function getDcv()
    {
        return $this->dcv;
    }
    
    public function isRenewed()
    {
        return $this->renewed;
    }
    
    public function getRenewedByTbsReference()
    {
        return $this->renewedByTbsReference;
    }
    
    protected function handleMessage()
    {
        if (!is_null($this->rawMessageResponse['demande'])) {
            if (is_array($this->rawMessageResponse['demande']) && (count($this->rawMessageResponse['demande']) > 0)
                    && !array_key_exists('codeReponse', $this->rawMessageResponse['demande'])) {
                $this->rawMessageResponse['demande'] = $this->rawMessageResponse['demande'][0];
            }
            $this->code = $this->rawMessageResponse['demande']['codeReponse'];
            // We squeeze that message as it is in French...
            //$this->message = $this->rawMessageResponse['demande']['messageReponse'];
            $this->message = \TBSCertBot\API\Helper::getErrorMessage($this->code);
        } elseif (!empty($this->rawMessageResponse['codeReponse'])) {
            $this->code = $this->rawMessageResponse['codeReponse'];
            $this->message = \TBSCertBot\API\Helper::getErrorMessage($this->code);
        } else {
            throw new \Exception("Invalid response from server (no 'demande' structure)");
        }
    }
}
