<?php

/*
 * This file is part of TBSCertBot.
 * 
 * Copyright (c) 1996-2016 TBS Internet
 * 
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

namespace TBSCertBot\API\Methods;

use PhpXmlRpc as XmlRpc;

/**
 * Base handler for XMLRPC Requests, to be inherited for API method implementations
 *
 * @author TBS Internet <webmaster@tbs-internet.com>
 */
abstract class XmlRpcRequest
{
    public $application;
    public $methodName;
    
    private static $rpcTypes = array(
        'dureeVie'          => 'int',
        'nbLicence'         => 'int',
        'keySize'           => 'int',
        'typeDemande'       => 'int',
        'civiliteAdm'       => 'int',
        'civiliteTech'      => 'int',
        'civiliteRespLegal' => 'int'
    );
    
    private $xmlRpcURL;
    private $xmlRpcMessage;
    private $xmlRpcValues;
    
    /**
     * 
     * Converts an array to an XML RPC structure
     * 
     * @param array $array
     * @return \PhpXmlRpc\Value
     */
    private static function arrayToXmlRpc(array $array)
    {
        $xmlRpc = false;
        if ($array && is_array($array)) {
            $xmlRpc = array();
            foreach ($array as $key => $value) {
                if ($value && is_array($value)) {
                    $xmlRpc[$key] = new XmlRpc\Value(self::arrayToXmlRpc($value), 'struct');
                } else {
                    if (isset(self::$rpcTypes[$key])) {
                        $type = self::$rpcTypes[$key];
                    } else {
                        $type = "string";
                    }
                    $xmlRpc[$key] = new XmlRpc\Value($value, $type);
                }
            }
        }
        return $xmlRpc;
    }
    
    /**
     * Creates the URL for cURL
     */
    private function setXmlRpcURL()
    {
        $this->xmlRpcURL =
                \TBSCertBot\Config::getConfig()->getAPIProtocol()
                . '://'
                . \TBSCertBot\Config::getConfig()->getAPIAddress()
                . ':'
                . \TBSCertBot\Config::getConfig()->getAPIPort()
                . '/'
                . $this->application;
    }
    
    private function setXmlRpcMessage()
    {
        $this->xmlRpcMessage = $this->methodName;
    }
    
    private function setXmlRpcValues()
    {
        $this->xmlRpcValues = $this->getXmlRpc();
    }
    
    abstract public function getXmlRpc();
    abstract protected function handleResponse($response);
    
    /**
     * Main sending function, not overwriten
     * @return variable Dependant on the class implementing handleResponse()
     */
    public final function send()
    {   
        $this->setXmlRpcURL();
        $this->setXmlRpcMessage();
        $this->setXmlRpcValues();
        
        $tmp = $this->xmlRpcValues;
        $this->xmlRpcValues = self::arrayToXmlRpc($tmp);
        
        $message = new XmlRpc\Request($this->xmlRpcMessage);
        $message->addParam(new XmlRpc\Value($this->xmlRpcValues, 'struct'));
        
        $client = new XmlRpc\Client($this->xmlRpcURL);
        
        if (\TBSCertBot\Config::getConfig()->getDebug()) {
            ob_end_flush();
            ob_start(function($chunk) {
                return preg_replace('/<member><name>motDePasse<\/name>\s*<value><string>.*<\/string><\/value>/', 
                                                            '<member><name>motDePasse</name>' . PHP_EOL . '<value><string>********</string></value>', 
                                                            $chunk);
            }, 4096);
            $client->setDebug(2);
        }
        
        $response = $this->handleResponse($client->send($message, \TBSCertBot\Config::getConfig()->getAPITimeout()));
        
        if (\TBSCertBot\Config::getConfig()->getDebug()) {
            ob_end_flush();
        }
        
        return $response;
    }
}
