<?php

/*
 * This file is part of TBSCertBot.
 * 
 * Copyright (c) 1996-2016 TBS Internet
 * 
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

namespace TBSCertBot\API\Methods;

use PhpXmlRpc as XmlRpc;

/**
 * Base handler for XMLRPC Responses, to be inherited for API method implementations
 *
 * @author TBS Internet <webmaster@tbs-internet.com>
 */
abstract class XmlRpcResponse
{
    protected $xmlRpcCode;
    protected $xmlRpcMessage;
   
    protected $rawMessageResponse;
    
    /**
     * 
     * @param XmlRpc\Response $xmlRpcResponse
     */
    public function __construct(XmlRpc\Response $xmlRpcResponse)
    {
        if ($xmlRpcResponse->faultCode() !== 0) {
            $this->xmlRpcCode = $xmlRpcResponse->faultCode();
            $this->xmlRpcMessage = $xmlRpcResponse->faultString();
        } else {
            $encoder = new XmlRpc\Encoder();
            $this->rawMessageResponse = $encoder->decode($xmlRpcResponse->value());
            unset($encoder);
            
            $this->handleMessage();
        }
    }
    
    public function getxmlRpcCode()
    {
        return $this->xmlRpcCode;
    }
    
    public function getxmlRpcMessage()
    {
        return $this->xmlRpcMessage;
    }
    
    public function getRawMessageResponse()
    {
        return $this->rawMessageResponse;
    }
    
    /**
     * Handler for the messages.
     */
    abstract protected function handleMessage();
}
