<?php

/*
 * This file is part of TBSCertBot.
 * 
 * Copyright (c) 1996-2016 TBS Internet
 * 
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

namespace TBSCertBot\CLI\Commands;

use Piwik\Ini as ConfigFileHelper;

/**
 * Export an order into an ini configuraiton file
 *
 * @author TBS Internet <webmaster@tbs-internet.com>
 */
class Export extends Command {
    private $profileName;
    private $filePath;
    
    public function __construct($profileName, $filePath)
    {
        parent::__construct();
        
        if (empty($profileName)) {
            $this->logger->log('You must provide a profile name to export', 'error');
            throw new \Exception("You must provide a profile name to export");
        }
        
        if (empty($filePath)) {
            $this->logger->log('You must profile a file path to export', 'error');
            throw new \Exception("You must profile a file path to export");
        }
        
        $this->profileName = $profileName;
        $this->logger->setFileName($profileName . '.log');
        
        if (is_dir($filePath)) {
            if (strpos($filePath, DIRECTORY_SEPARATOR) === (strlen($filePath) - 1)) {
                $this->filePath = $filePath . $profileName . '.ini';
            } else {
                $this->filePath = $filePath . DIRECTORY_SEPARATOR . $profileName . '.ini';
            }
        } else {
            $this->filePath = $filePath;
        }
        
    }
    
    /**
     * Filters a profile to only contain export-ready data
     * 
     * @param array $profile
     * @return array
     */
    private function filterProfile($profile)
    {
        $keys = ['PRODUCT', 'REQUEST', 'PAYMENT', 'MISCELLANEOUS', 'ORGANIZATION',
            'TECHNICAL_CONTACT', 'CORPORATE_CONTACT', 'LEGAL_CONTACT', 'LEGAL_CONTACT'];

        $profileToExport = [];
        
        //We iterate on those keys instead of a more concise method because array_filter cannot work with keys until PHP 5.6
        foreach($keys as $key) {
            if (array_key_exists($key, $profile)) {
                $profileToExport[$key] = $profile[$key];
            }
        }
        
        //We filter dangerous fields
        if (array_key_exists('REQUEST', $profileToExport)) {
            if (array_key_exists('uniqueIdentifier', $profileToExport['REQUEST'])) {
                unset($profileToExport['REQUEST']['uniqueIdentifier']);
            }
            
            if (array_key_exists('domainControlValidationUniqueValue', $profileToExport['REQUEST'])) {
                unset($profileToExport['REQUEST']['domainControlValidationUniqueValue']);
            }
        }
        
        return $profileToExport;
    }
    
    public function proceed() 
    {
        $profile = \TBSCertBot\Controllers\Profile::getProfiles($this->profileName);
        
        $profileToExport = $this->filterProfile($profile[0]);
        
        //Now, we write
        
        $writer = new ConfigFileHelper\IniWriter();
        
        $writer->writeToFile($this->filePath, $profileToExport);
        
        \cli\line("The configuration has been exported to " . realpath($this->filePath));
        $this->logger->log("The configuration has been exported to " . realpath($this->filePath), 'info');
    }
    
    public function runHook($tbsReference = null)
    {
        //Do nothing
    }
}
