<?php

/*
 * This file is part of TBSCertBot.
 * 
 * Copyright (c) 1996-2016 TBS Internet
 * 
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

namespace TBSCertBot\CLI\Commands;

/**
 * Imports a certificate into TBSCertBot's database.
 * To be implemented.
 *
 * @author TBS Internet <webmaster@tbs-internet.com>
 */
class Import extends Command
{
    private$filePath;
    
    public function __construct($filePath)
    {
        parent::__construct();
            
        if (empty($filePath)) {
            $this->logger->log('Missing file path to the profile to import.', 'error');
            throw new \Exception("Missing file path to the profile to import.");
        }
        
       $this ->filePath = $filePath;
    }
    
    public function proceed()
    {
        $json = file_get_contents($this->filePath);
        
        if (empty($json)) {
            $this->logger->log("The file provided (" . $this->filePath . ") is missing or empty.", 'error');
            throw new \Exception("The file provided (" . $this->filePath . ") is missing or empty.");
        }
        
        try {
            $profile = \TBSCertBot\JsonDriver::getJsonDriver()->decode($json, true);
        
            \TBSCertBot\Controllers\Profile::setProfile($profile);
            
            \cli\line('The profile from file ' . $this->filePath . ' has been imported successfully.');
        } catch (\Exception $e) {
            $this->logger->log('Error reading file ' . $this->filePath . ': ' . $e->getMessage());
            throw new \Exception('Error reading file ' . $this->filePath . ': ' . $e->getMessage(), $e->getCode());
        }

    }
    
    protected function runHook($tbsReference = NULL)
    {
        //No hook to run for imports
    }
}
