<?php

/*
 * This file is part of TBSCertBot.
 * 
 * Copyright (c) 1996-2016 TBS Internet
 * 
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

namespace TBSCertBot\CLI\Commands;

/**
 * Recover command used to get "lost" orders without a reference
 *
 * @author TBS Internet <webmaster@tbs-internet.com>
 */
class Recover extends Command
{
    /**
     *
     * @var array List of all UUID
     */
    private $uuidList;

/**
 * 
 * @param string $uuid A UUIDv4 generated during the Order/Renew command
 * @throws \Exception
 */
    public function __construct($uuid = null) {
        parent::__construct();
        
        if (isset($uuid)) {
            try {
                if (\TBSCertBot\Crypto\Helper::isUuid($uuid)) {
                    $this->uuidList[0] = $uuid;
                } else {
                    $this->logger->log("Parameter \"$uuid\" is not a valid UUID.", 'error');
                    throw new \Exception("Parameter \"$uuid\" is not a valid UUID.");
                }
            } catch (\Exception $e) {
                $this->logger->log($e->getMessage(), 'error');
                throw $e;
            }
        }
        
        $profiles = \TBSCertBot\Controllers\Profile::getProfiles($uuid);
        
        if (empty($uuid)) {
            foreach ($profiles AS $profile) {
                if (empty($profile['CERTIFICATE']['tbsReference'])) {
                    $this->uuidList[] = $profile['REQUEST']['uniqueIdentifier'];
                }
            }
        }
    }
    
    public function proceed()
    {
        //We can enter this case if we call the recover command without parameters
        if (empty($this->uuidList)) {
            $this->logger->log('No order to recover', 'info');
            \cli\line("No order to recover.");
        } else {
            foreach ($this->uuidList as $uuid) {
                try {
                    \cli\line("Attempting to recover order $uuid");
                    $this->logger->appendToBuffer("Attempting to recover order $uuid", 'info');
                    $recoverable = new \TBSCertBot\Controllers\Recoverable($uuid);

                    //Main "fixing"
                    $recoverable->recover();
                    $recoverable->fixFile();

                    //Cannot dereference function returns before PHP5.5
                    $tbsReference = $recoverable->getTbsReference();
                    
                    //If the user didn't skip the recovery, we will have a TBS Reference
                    if (!empty($tbsReference)) {
                        \cli\line("Recovered order $uuid with TBS Reference $tbsReference");
                        
                        $this->logger->appendToBuffer("Recovered order $uuid with TBS Reference $tbsReference", 'info');
                        $this->logger->setFileName($tbsReference . '.log');
                        $this->logger->commit();
                        
                        \cli\line();
                    }
                } catch (\Exception $e) {
                    $this->logger->appendToBuffer($e->getMessage(), 'error');
                    $this->logger->setFileName($uuid . '.log');
                    $this->logger->commit();
                    throw $e;
                }
            }
        }
    }
    
    protected function runHook($tbsReference = null)
    {
        //Do nothing
    }
}
