<?php

/*
 * This file is part of TBSCertBot.
 * 
 * Copyright (c) 1996-2016 TBS Internet
 * 
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

namespace TBSCertBot\CLI\Commands;

/**
 * Description of Resend
 *
 * @author TBS Internet <webmaster@tbs-internet.com>
 */
class Resend extends Command
{
    private $profiles = array();
    
    /**
     * 
     * @param type $tbsReference optional TBS Reference to resend the dcf for only one certificate
     */
    public function __construct($tbsReference = null)
    {
        parent::__construct();

        //$this->setArguments();
        //$this->parseArguments();
        //$this->mergeOptionsWithConfig($this->arguments->getArguments());
        $this->profiles = \TBSCertBot\Controllers\Profile::getProfiles($tbsReference);
    }

    public function proceed()
    {
        foreach ($this->profiles as $profile) {

            if ($profile['LAST_KNOWN_STATUS']['code'] != 1) {
                $this->logger->setFileName($profile['CERTIFICATE']['tbsReference'] . '.log');

                \cli\line();
                
                \cli\line('Asking DCV e-mail resending for certificate reference ' 
                        . $profile['CERTIFICATE']['tbsReference'] 
                        . ' (CN = ' . $profile['CSR']['commonName'] . ').');
                
                $this->logger->appendToBuffer('Asking DCV e-mail resending for certificate reference ' 
                        . $profile['CERTIFICATE']['tbsReference'] 
                        . ' (CN = ' . $profile['CSR']['commonName'] . ').', 'info');
                
                $resend = new \TBSCertBot\API\Methods\DCVEmailResend\Request(
                        $profile['CERTIFICATE']['tbsReference']
                );
                
                $response = $resend->send();

                if ($response->getCode() == 0) {
                    \cli\line('   -> DCV e-mail correctly resent, please proceed the challenge.');
                    $this->logger->appendToBuffer('   -> DCV e-mail correctly resent, please proceed the challenge.', 'info');
                } else {
                    \cli\err('   -> An error occured while resending the challenge.');
                    $this->logger->appendToBuffer('   -> An error occured while resending the challenge.', 'error');
                }
                \cli\line();
                
                $this->logger->commit();
            }
        }
    }
    
    protected function runHook()
    {

    }
}
