<?php

/*
 * This file is part of TBSCertBot.
 * 
 * Copyright (c) 1996-2016 TBS Internet
 * 
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

namespace TBSCertBot\CLI\Commands;

/**
 * Shows a list of all handled certificates with information
 *
 * @author TBS Internet <webmaster@tbs-internet.com>
 */
class Show extends Command
{
    protected $profiles;
    
    public function __construct()
    {
        parent::__construct();

        $this->profiles = \TBSCertBot\Controllers\Profile::getProfiles();
    }
    
    public function proceed()
    {   
        if (!empty($this->profiles)) {
            $table = new \cli\Table();
            $table->setHeaders(array('#', 'reference', 'CN', 'state', 'extra state info', 'issuance date', 'expiration date'));
            $rows = array();

            $i = 0;
            foreach ($this->profiles as $profile) {
                //Display expired statis if the expiration date is passed
                unset($date);
                if($profile['LAST_KNOWN_STATUS']['code'] == 1) {
                    $utc = new \DateTimeZone('UTC');
                    
                    $date = new \DateTime($profile['CERTIFICATE']['endDate'], $utc);
                    $dateNow = new \DateTime('now', $utc);
                    
                    if ($date < $dateNow) {
                        //We set the message we'll return to expired.
                        //For compatibility with legacy PHP versions (PHP 5.3), we can't dereference the returned array
                        $tbsStatuses = \TBSCertBot\API\Methods\Status\Response::getTbsStatus();
                        $profile['LAST_KNOWN_STATUS']['message'] = $tbsStatuses[2];
                    }
                }
                
                //Ternary conditions used in case the value is empty
                array_push($rows, array(
                    $i + 1,
                    (isset($profile['CERTIFICATE']['tbsReference'])) ? $profile['CERTIFICATE']['tbsReference'] : '',
                    (isset($profile['CSR']['commonName'])) ? $profile['CSR']['commonName'] : '',
                    (isset($profile['LAST_KNOWN_STATUS']['message'])) ? $profile['LAST_KNOWN_STATUS']['message'] : '',
                    (isset($profile['LAST_KNOWN_STATUS']['messageExtra'])) ? $profile['LAST_KNOWN_STATUS']['messageExtra'] : '',
                    (isset($profile['CERTIFICATE']['beginDate'])) ? $profile['CERTIFICATE']['beginDate'] : '',
                    (isset($profile['CERTIFICATE']['endDate'])) ? $profile['CERTIFICATE']['endDate'] : ''
                ));
                $i++;
            }
            $table->setRows($rows);

            \cli\line();
            $table->display();
            \cli\line();
        } else {
            \cli\line('There isn\'t any certificate to show yet.');
            $this->logger->log('There isn\'t any certificate to show yet.', 'warn');
        }
    }
    
    /**
     * 
     * @param \cli\Arguments $arguments
     * @todo Document "all" flag
     */
    public static function setArguments(\cli\Arguments &$arguments)
    {
        $arguments->addFlag('all', 'TODO');
        $arguments->addOption('tbs-ref', array('description' => 'TBS Reference'));
    }

    private static function mergeOptionsWithConfig($options)
    {   
        $config = array();
        
        if (isset($options['directory-']) && !is_null($options['directory-reqs'])) {
            $config['DIRECTORIES']['requests'] = $options['directory-reqs'];
        }
        
        if (!empty($config)) {
            \TBSCertBot\Config::getConfig()->update($config);
        }
    }
    
    protected function runHook($tbsReference = null)
    {

    }
}
