<?php

/*
 * This file is part of TBSCertBot.
 * 
 * Copyright (c) 1996-2016 TBS Internet
 * 
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

namespace TBSCertBot\CLI\Commands;

/**
 * Gets the status of an order
 *
 * @author TBS Internet <webmaster@tbs-internet.com>
 */
class Status extends Command
{
    private static $DCV_DIRECTORY; //TODO: Shouldn't this be a configurable directory?
    
    private $statusCode;
    private $statusMessage;
    private $statusMessageExtra;
    
    private $certificatePEM;
    private $chainPEM;
    
    private $beginDate;
    private $endDate;
    
    private $dcv;
    
    public function __construct($tbsReference)
    {
        parent::__construct();
        
        //$this->setArguments();
        //$this->parseArguments();
        //$this->mergeOptionsWithConfig($this->arguments->getArguments());
            
        $this->profile = \TBSCertBot\Controllers\Profile::getProfiles($tbsReference);
        $this->profile = $this->profile[0];
        
        $this->logger->setFileName($this->profile['CERTIFICATE']['tbsReference'] . '.log');
        
        try {
            $status = new \TBSCertBot\API\Methods\Status\Request(
                        new \TBSCertBot\API\Entities\Certificate(
                        $this->profile['CERTIFICATE']['caReference'], $this->profile['CERTIFICATE']['tbsReference']
                ));

            $statusResponse = $status->send();

            $this->statusCode = $statusResponse->getStatusCode();
            $this->statusMessage = $statusResponse->getStatusMessage();
            $this->statusMessageExtra = $statusResponse->getStatusMessageExtra();

            $this->certificatePEM = $statusResponse->getCertificatePEM();
            $this->chainPEM = $statusResponse->getChainPEM();
            $this->beginDate = $statusResponse->getbeginDate();
            $this->endDate = $statusResponse->getEndDate();

            $this->dcv = $statusResponse->getDcv();
        } catch (\Exception $e) {
            \cli\line("Error: " . $e->getMessage());
            $this->logger->appendToBuffer("Error: " . $e->getMessage(), 'error');
        }
        
    }
    
    private static function getDcvDirectory()
    {
        if (empty(self::$DCV_DIRECTORY)) {
            self::$DCV_DIRECTORY = 'data'. DIRECTORY_SEPARATOR . 'dcv';
        }
        
        return self::$DCV_DIRECTORY;
    }
    
    public function proceed()
    {
        try {
            \cli\line("Order status:");
            $this->logger->appendToBuffer('Order status:', 'info');
            \cli\line("  Status message: " . $this->getStatusMessage());
            $this->logger->appendToBuffer("  Status message: " . $this->getStatusMessage(), 'info');
            \cli\line("  Extra information: " . $this->getStatusMessageExtra());
            $this->logger->appendToBuffer("  Extra information: " . $this->getStatusMessageExtra(), 'info');

            if ($this->getCertificatePEM()) {
                \cli\line("  Certificate:");
                $this->logger->appendToBuffer('  Certificate:', 'info');
                
                \cli\line("    Certificate:");
                $this->logger->appendToBuffer('    Certificate:', 'info');
                \cli\line($this->getCertificatePEM());
                $this->logger->appendToBuffer($this->getCertificatePEM(), 'info');
                
                if ($this->profile['CERTIFICATE']['certificatePEMFile']) {
                    \cli\line("    Certificate File: " . $this->profile['CERTIFICATE']['certificatePEMFile']);
                    $this->logger->appendToBuffer("    Certificate File: " . $this->profile['CERTIFICATE']['certificatePEMFile'], 'info');
                }
                
                \cli\line();
                
                \cli\line("    Chain:");
                $this->logger->appendToBuffer('    Chain:"', 'info');
                \cli\line($this->getChainPEM());
                $this->logger->appendToBuffer($this->getChainPEM(), 'info');
                
                if ($this->profile['CERTIFICATE']['chainPEMFile']) {
                    \cli\line("    Chain File: " . $this->profile['CERTIFICATE']['chainPEMFile']);
                    $this->logger->appendToBuffer("    Chain File: " . $this->profile['CERTIFICATE']['chainPEMFile'], 'info');
                }
                
                \cli\line();
                
                \cli\line("    Begining date: " . $this->getBeginDate());
                $this->logger->appendToBuffer("    Begining date: " . $this->getBeginDate(), 'info');
                \cli\line("    End date: " . $this->getEndDate());
                $this->logger->appendToBuffer("    End date: " . $this->getEndDate(), 'info');
            } else {
                $this->displayDcv(1);
            }
        } catch (\Exception $e) {
            \cli\err("Error: " . $e->getMessage());
            $this->logger->appendToBuffer("Error: " . $e->getMessage(), 'error');
        }
    }

    public function getStatusCode()
    {
        return $this->statusCode;
    }
    
    public function getStatusMessage()
    {
        return $this->statusMessage;
    }
    
    public function getStatusMessageExtra()
    {
        return $this->statusMessageExtra;
    }
    
    public function getCertificatePEM()
    {
        return $this->certificatePEM;
    }
    
    public function getChainPEM()
    {
        return $this->chainPEM;
    }
    
    public function getBeginDate()
    {
        return $this->beginDate;
    }
    
    public function getEndDate()
    {
        return $this->endDate;
    }
    
    public function getDcv()
    {
        return $this->dcv;
    }
    
    public function displayDcv($indent)
    {
        if ($this->dcv) {
            $originalIndent = $indent;
            $spaces = str_repeat(' ', $indent * 2);
            \cli\line($spaces . "DCV:");
            $this->logger->appendToBuffer($spaces . "DCV:", 'info');

            foreach ($this->dcv as $san => $dcv) {
                //If we're dones with SANs, we leave the foreach
                if (!strpos($san, '.')) break;


                $indent += 1;
                $spaces = str_repeat(' ', $indent * 2);

                \cli\line($spaces . $san . ":");

                $indent += 1;
                $spaces = str_repeat(' ', $indent * 2);

                if (!empty($dcv['DCV_Selected'])) {
                    \cli\line($spaces . 'DCV Method: ' . $dcv['DCV_Selected']);
                    $this->logger->appendToBuffer($spaces . 'DCV Method: ' . $dcv['DCV_Selected'], 'info');

                    if (strpos($dcv['DCV_Selected'], '@')) {
                        if ($dcv['DCV_ValidEmails']) {
                            \cli\line($spaces . 'DCV Valid Emails:');
                            $this->logger->appendToBuffer($spaces . 'DCV Valid Emails:', 'info');

                            $indent += 1;
                            $spaces = str_repeat(' ', $indent * 2);

                            foreach ($dcv['DCV_ValidEmails'] as $email) {
                                \cli\line($spaces . $email);
                                $this->logger->appendToBuffer($spaces . $email, 'info');
                            }

                            $indent -= 1;
                            $spaces = str_repeat(' ', $indent * 2);
                        }
                    } elseif ($dcv['DCV_Selected'] === 'HTTP_CSR_HASH'
                    || $dcv['DCV_Selected'] === 'HTTPS_CSR_HASH') {
                        if ($dcv['DCV_Check']) {
                            if ($dcv['DCV_Check'] === "Fichier par encore accessible sur votre serveur."
                            || $dcv['DCV_Check'] === "Fichier pas encore accessible sur votre serveur.") {
                                
                                \cli\line($spaces . 'DCV Status: The file is not available yet on your server');
                                $this->logger->appendToBuffer($spaces . 'DCV Status: The file is not available yet on your server', 'info');
                            } 
                        } elseif ($dcv['DCV_Checked']) {
                            if (strpos($dcv['DCV_Checked'], "Le fichier DCV a été trouvé à l'adresse")) {
                                \cli\line($spaces . 'DCV Status: The file has been found at the address'
                                        . $dcv['DCV_Url'] . ' and validates the SAN.');
                                
                                $this->logger->appendToBuffer($spaces . 'DCV Status: The file has been found at the address'
                                        . $dcv['DCV_Url'] . ' and validates the SAN.', 'info');
                            }
                        }

                        //In any case, displaying the checked URL
                        if ($dcv['DCV_Url']) {
                            \cli\line($spaces . 'DCV Checked URL: ' . $dcv['DCV_Url']);
                            $this->logger->appendToBuffer($spaces . 'DCV Checked URL: ' . $dcv['DCV_Url'], 'info');
                        }

                        /* If we can get a DCV file savec by Certbot, we display its path
                         * If we cannot, we display the filename and the content from the API, if available 
                         */
                        //PHP 5.3 compat: no array dereferencement
                        $dcv = $this->getDcv();
                        
                        if ($dcv['DCV_File_Name']) {
                            if (is_file(\TBSCertBot\Helper::getDirectory(self::getDcvDirectory()) . DIRECTORY_SEPARATOR . $dcv['DCV_File_Name'])) {
                                \cli\line($spaces . 'DCV File: ' . \TBSCertBot\Helper::getDirectory(self::getDcvDirectory()) . DIRECTORY_SEPARATOR . $dcv['DCV_File_Name']);
                                $this->logger->appendToBuffer($spaces . 'DCV File: ' . \TBSCertBot\Helper::getDirectory(self::getDcvDirectory()) . DIRECTORY_SEPARATOR . $dcv['DCV_File_Name'], 'info');
                            }
                        } elseif ($dcv['DCV_File_Name'] && $dcv['DCV_File_Content']) {
                            \cli\line($spaces . 'DCV Filename: ' . $dcv['DCV_File_Name']);
                            $this->logger->appendToBuffer($spaces . 'DCV Filename: ' . $dcv['DCV_File_Name'], 'info');
                            \cli\line($spaces . 'DCV File contents (there should be on line feed character and no supplementary whitespace):');
                            $this->logger->appendToBuffer($spaces . 'DCV File contents (there should be on line feed character and no supplementary whitespace):', 'info');
                            \cli\line($dcv['DCV_File_Content']);
                            $this->logger->appendToBuffer($dcv['DCV_File_Content'], 'info');
                        }
                    } elseif ($dcv['DCV_Selected'] === 'CNAME_CSR_HASH') {
                        if ($dcv['DCV_Check'] === "Enregistrement CNAME pas encore lisible sur votre serveur DNS.") {
                            \cli\line($spaces . 'DCV Status: The CNAME record is not yet in your DNS zone');
                            $this->logger->appendToBuffer($spaces . 'DCV Status: The CNAME record is not yet in your DNS zone', 'info');
                        } elseif (strpos("et valide ainsi le CN", $dcv['DCV_Checked'])) {
                            \cli\line($spaces . 'DCV Status: The CNAME record has been found in the DNS zone and validates the SAN.');
                            $this->logger->appendToBuffer($spaces . 'DCV Status: The CNAME record has been found in the DNS zone and validates the SAN.', 'info');
                        }

                        //In any case, displaying the needed CNAME Record
                        if ($dcv['DCV_CNAME_Record']) {
                            \cli\line($spaces . 'DCV CNAME Record: ' . $dcv['DCV_CNAME_Record']);
                            $this->logger->appendToBuffer($spaces . 'DCV CNAME Record: ' . $dcv['DCV_CNAME_Record'], 'info');
                        }
                    }

                    //For forward compatibility. We should not at the moment get any error.
                    if (!empty($dcv['DCV_Error'])) {
                        \cli\err($spaces . 'DCV Error: ' . $dcv['DCV_Error']);
                        $this->logger->appendToBuffer($spaces . 'DCV Error: ' . $dcv['DCV_Error'], 'error');
                    }

                }

                $indent = $originalIndent;
                $spaces = str_repeat(' ', $indent * 2);
            }
        }
    }
    
    public static function setArguments(\cli\Arguments &$arguments)
    {
        
    }
    
    protected function runHook($tbsReference = null)
    {

    }
}
