<?php

/*
 * This file is part of TBSCertBot.
 * 
 * Copyright (c) 1996-2016 TBS Internet
 * 
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

namespace TBSCertBot\Crypto;

/**
 * RSA Private Key class
 *
 * @author TBS Internet <webmaster@tbs-internet.com>
 */
class RSA extends PrivateKey
{
    const TYPE = 'RSA';
    const ALGORITHM = OPENSSL_KEYTYPE_RSA;
    const DEFAULT_KEY_SIZE = 2048;
    
    private $length;
    
    /**
     * 
     * @param string $fileName Full path to the future Key
     * @param int $length
     */
    public function __construct($fileName = null, $length = self::DEFAULT_KEY_SIZE)
    {
        parent::__construct($fileName);

        $this->length = $length;
    }
    
    public function generate()
    {
        $config = array(
            'private_key_type' => (int) self::ALGORITHM,
            'private_key_bits' => (int) $this->length
        );
        
        $this->keyResource = openssl_pkey_new($config);
        
        if ($this->keyResource == false) {
            throw new \Exception('Private key could not be generated.');
        }
        
        try {
            $this->exportToFile();
        } catch (\Exception $e) {
            throw $e;
        }
    }
    
    /**
     * Returns the base64 (aka pem) Private key
     * 
     * @return string
     * @throws \Exception
     */
    public function getASCII()
    {
        $ascii = '';
        $status = openssl_pkey_export($this->keyResource, $ascii);
        
        if (!$status) {
            throw new \Exception('Private key has not been generated yet.');
        }
        return trim($ascii);
    }
    
    public function display()
    {
        \cli\line('   - Type = ' . self::TYPE);
        \cli\line('   - Length = ' . $this->length);
        \cli\line('   - Path = ' . $this->fileName);
    }
    
    public function changeFilePath()
    {
        
    }
    
    public function save()
    {
        $info = array();
        
        $info['type'] = self::TYPE;
                
        if (isset($this->length) && !is_null($this->length)) {
            $info['length'] = $this->length;
        }
        if (isset($this->fileName) && !is_null($this->fileName)) {
            $info['fileName'] = realpath($this->fileName);
        }
        
        return $info;
    }
    
    /**
     * @todo Finish coding this function.
     * @param type $filePath
     * @throws \Exception
     */
    public static function load($filePath)
    {
        try {
            $ressource = openssl_pkey_get_private(file_get_contents($filePath));
            
        } catch (\Exception $e) {
            throw $e;
        }
    }
}
