<?php

/*
 * This file is part of TBSCertBot.
 * 
 * Copyright (c) 1996-2016 TBS Internet
 * 
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

namespace TBSCertBot;

/**
 * Main project-wide Helper class
 *
 * @author TBS Internet <webmaster@tbs-internet.com>
 * @todo Relocate this file to FS namespace (if created)?
 */
abstract class Helper {

    /**
     * 
     * Static function that returns an available filePath for future writing
     * given an initial filePath.
     * 
     * @param string $filePath
     * @return string return an available filePath on the FS.
     * @todo Check portability on Windows.
     */
    public static function getOrIncrementFileName($filePath) {
        if (!file_exists($filePath)) { // File doesn't exist so it is available.
            return $filePath;
        } else { // File with format www.tbs-internet.com-2016-05-11.key already exists.
            $info = pathinfo($filePath);
            $basename = basename($filePath, '.' . $info['extension']);
            $matches = array();
            if (preg_match('/\_[[:digit:]]*/', $basename, $matches)) {
                // Found a file with format www.tbs-internet.com-2016-05-11_1.key
                // We increment the last digit before extension and check if it is available.
                $num = (int) str_replace('_', '', $matches[count($matches) - 1]);

                return self::getOrIncrementFileName(
                                $info['dirname']
                                . DIRECTORY_SEPARATOR
                                . substr($basename, 0, strlen($basename) - (strlen($matches[count($matches) - 1])))
                                . '_'
                                . (string) ($num + 1)
                                . '.'
                                . $info['extension']
                );
            } else {
                // There isn't any file with format www.tbs-internet.com-2016-05-11_1.key
                // So we create it with last digit = 1 before extension and check if it is available.
                return self::getOrIncrementFileName(
                                $info['dirname']
                                . DIRECTORY_SEPARATOR
                                . $basename
                                . '_1'
                                . '.'
                                . $info['extension']
                );
            }
        }
    }
    
    public static function array_flatten($array) {
        $return = array();
        foreach ($array as $key => $value) {
            if (is_array($value)){
                $return = array_merge($return, \TBSCertBot\Helper::array_flatten($value));
            } else {
                $return[$key] = $value;
            }
        }
        return $return;
    }
    
    /**
     * Checks if a directory exists and create it if it does not exist
     * 
     * @param string $path Path to the directory we try to check
     * @return string the queried directory
     * @throws \Exception If we cannot create a directory
     */
    public static function getDirectory($path) {
        //All three PHP functions to handle files return a boolean based on success
        
        $realPath = realpath($path);
        
        //If the path did not exist, we use the provided path as is
        if (!$realPath) $realPath = $path;
        
        if (!is_dir($realPath)) {
            $status = mkdir($realPath);
        
            if (!$status) {
                throw new \Exception(sprintf("Cannot create %s directory.", $realPath));
            }
        }
        
        return $realPath;
    }
    
    /**
     * 
     * Exception handler that throws and ErrorException for errors above the error reporting level
     * 
     * @param int $severity
     * @param string $message
     * @param string $file
     * @param int $line
     * @return void
     * @throws \ErrorException
     */
    public static function exception_error_handler($severity, $message, $file, $line) {
        if (!(error_reporting() & $severity)) {
            // This error code is not included in error_reporting
            return;
        }
    
        throw new \ErrorException($message, 0, $severity, $file, $line);
}

}
