<?php

/*
 * This file is part of TBSCertBot.
 * 
 * Copyright (c) 1996-2019 TBS Internet
 * 
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

namespace TBSCertBot;

/**
 * Description of LogDriver
 *
 * @author rmussard
 */
class Logger {
    private $directory;
    private $fileName;
    
    private $handle;
    
    private $buffer;
    
    public function __construct($fileName = "")
    {
        $this->directory = Config::getConfig()->getLogsDirectoryPath();
        
        if ($fileName) {
            $this->setFileName($fileName);
        } else {
            $this->resetFileName();
        }
        
        $this->buffer = '';
    }
    
    public function __destruct()
    {
        if (!empty($this->buffer)) {
            $this->commit();
        }
        
        if ($this->handle instanceof SplFileObject) {
            unset($this->handle);
        }
    }
    
    public function setFileName($fileName)
    {
        $this->fileName = ($fileName);
        unset($this->handle);
    }
    
    public function resetFileName()
    {
        $this->fileName = 'tbscertbot.log';
        unset($this->handle);
    }
    
    private function open()
    {
        if (!($this->handle instanceof SplFileObject)) {
            //Note: I would be using realpath here, if it worked on non existing files.
            $this->handle = new \SplFileObject($this->directory . DIRECTORY_SEPARATOR  . $this->fileName, 'a');
        }
    }
    
    public function appendToBuffer($message, $level = 'error') {
        if (self::CheckLogLevel($level)) {
            $this->buffer .= '[' . date('c') . "]\t" . $message . PHP_EOL;
        }
    }
    
    private function write($message) {
        $this->open();

        $this->handle->fwrite($message);
    }
    
    public function commit()
    {
        if (!empty($this->buffer)) {
            $this->write($this->buffer);
        }
        
        $this->buffer = '';
    }
    
    public function log($message, $level = 'error')
    {
        if (self::CheckLogLevel($level)) {
            $this->write('[' . date('c') . "]\t" . $message . PHP_EOL);
        }
    }

    public static function CheckLogLevel($level)
    {
        $levelList = array_flip(['error', 'warn', 'info', 'debug']);
        
        if ($levelList[$level] <= $levelList[Config::getConfig()->getLogLevel()]) {
            return true;
        } else {
            return false;
        }
    }
}
